.. django-sitemapper documentation master file, created by
   sphinx-quickstart on Sat Oct  4 22:39:45 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-sitemapper's documentation!
=============================================


Sitemapper is a Django app to manage sitemap.xml overrides on a
per-object basis.

Migrations are provided for both Django 1.7+ and earlier versions using
`South <http://south.aeracode.org/>`_.



Getting started
---------------

The first thing you'll need to do is check out the
:doc:`installation guide and requirements</install>`.

If you're familiar with installing Django apps then the installation is totally
standard, with no additional dependencies.



Contribute
----------

- Issue Tracker: https://bitbucket.org/mhurt/django-sitemapper/issues
- Source Code: https://bitbucket.org/mhurt/django-sitemapper/


License
-------

The project is licensed under the MIT license.


.. toctree::
   :maxdepth: 2
   :hidden:

   install
   sitemaps
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`

